#ifndef __GEDIT_FILE_BROWER_MESSAGES_MESSAGES_H__
#define __GEDIT_FILE_BROWER_MESSAGES_MESSAGES_H__

#include "gedit-file-browser-message-activation.h"
#include "gedit-file-browser-message-add-filter.h"
#include "gedit-file-browser-message-extend-context-menu.h"
#include "gedit-file-browser-message-get-root.h"
#include "gedit-file-browser-message-get-view.h"
#include "gedit-file-browser-message-id.h"
#include "gedit-file-browser-message-id-location.h"
#include "gedit-file-browser-message-set-emblem.h"
#include "gedit-file-browser-message-set-markup.h"
#include "gedit-file-browser-message-set-root.h"

#endif /* __GEDIT_FILE_BROWER_MESSAGES_MESSAGES_H__ */

